/*
 * Simple commandline argument processing function
 * Programmed and designed by Matti 'ccr' Hamalainen
 * (C) Copyright 2002-2004 Tecnic Software productions (TNSP)
 *
 * Please read file 'COPYING' for information on license and distribution.
 */
#ifndef _TH_ARGS
#define _TH_ARGS
#include <stdio.h>

typedef struct {
	int optID;
	char shortOpt;
	char *longOpt;
	char *optDesc;
	int hasArg;
} t_opt;


void th_processArgs(int argc, char *argv[],
	t_opt argList[], int argListN,
	void (*handleOpt)(int, char *, char *),
	void (*handleFile)(char *));

void th_showHelp(FILE *, t_opt optList[], int optListN, char *, char *);

#endif /* _TH_ARGS */
